@@ -35,6 +35,7 @@ from __future__ import division, print_function, absolute_import
 from builtins import range
 
 import warnings
+from itertools import cycle
 
 # Numeric imports
 import numpy as np
@@ -288,7 +289,8 @@ def _burst_info(d, ich, burst_index):
     return msg.format(**params)
 
 
-def _plot_bursts(d, i, tmin_clk, tmax_clk, pmax=1e3, pmin=0, color="#999999"):
+def _plot_bursts(d, i, tmin_clk, tmax_clk, pmax=1e3, pmin=0, color="#999999",
+                 ytext=20):
     """Highlights bursts in a timetrace plot."""
     b = d.mburst[i]
     if b.num_bursts == 0:
@@ -301,13 +303,15 @@ def _plot_bursts(d, i, tmin_clk, tmax_clk, pmax=1e3, pmin=0, color="#999999"):
     R = []
     width = end - start
     ax = gca()
-    for b, bidx, s, w in zip(bs, burst_indices, start, width):
+    for b, bidx, s, w, sign, va in zip(bs, burst_indices, start, width,
+                                       cycle([-1, 1]),
+                                       cycle(['top', 'bottom'])):
         r = Rectangle(xy=(s, pmin), height=pmax - pmin, width=w)
         r.set_clip_box(ax.bbox)
         r.set_zorder(0)
         R.append(r)
-        ax.text(s, -20, _burst_info(d, i, bidx), fontsize=6, rotation=45,
-                horizontalalignment='center')
+        ax.text(s, sign * ytext, _burst_info(d, i, bidx), fontsize=6, rotation=45,
+                horizontalalignment='center', va=va)
     ax.add_artist(PatchCollection(R, lw=0, color=color))
 
 
@@ -826,7 +830,7 @@ def hist_width(d, i=0, bins=(0, 10, 0.025), pdf=True, weights=None,
 
 def hist_brightness(d, i=0, bins=(0, 60, 1), pdf=True, weights=None,
                     yscale='log', gamma=1, add_naa=False, beta=1.,
-                    donor_ref=True, add_aex=True, A_laser_weight=1,
+                    donor_ref=True, add_aex=True, aex_corr=True,
                     label_prefix=None, color=None, plot_style=None, vline=None):
     """Plot histogram of burst brightness, i.e. burst size / duration.
 
@@ -843,8 +847,8 @@ def hist_brightness(d, i=0, bins=(0, 60, 1), pdf=True, weights=None,
         add_aex (bool): *PAX-only*. Whether to add signal from Aex laser period
             to the burst size. Default True.
             See :meth:`fretbursts.burstlib.Data.burst_sizes_pax_ich`.
-        A_laser_weight (scalar): *PAX-only*. Weight of A-ch photons during Aex
-            period (AexAem) due to the A laser.
+        aex_corr (bool): *PAX-only*. If True, do duty-cycle correction
+            when adding the DAexAem term `naa`.
             See :meth:`fretbursts.burstlib.Data.burst_sizes_pax_ich`.
         label_prefix (string or None): a custom prefix for the legend label.
         color (string or tuple or None): matplotlib color used for the plot.
@@ -859,18 +863,11 @@ def hist_brightness(d, i=0, bins=(0, 60, 1), pdf=True, weights=None,
         plot_style = {}
 
     burst_widths = d.mburst[i].width * d.clk_p * 1e3
-    if 'PAX' in d.meas_type:
-        sizes = d.burst_sizes_pax_ich(ich=i, gamma=gamma, beta=beta,
-                                      donor_ref=donor_ref, add_aex=add_aex,
-                                      A_laser_weight=A_laser_weight)
-    else:
-        sizes = d.burst_sizes_ich(ich=i, gamma=gamma, beta=beta,
-                                  add_naa=add_naa, donor_ref=donor_ref)
+    sizes, label = _get_sizes_and_formula(
+        d=d, ich=i, gamma=gamma, beta=beta, donor_ref=donor_ref,
+        add_naa=add_naa, add_aex=add_aex, aex_corr=aex_corr)
     brightness = sizes / burst_widths
-    label = 'nd + na/g' if donor_ref else 'g*nd + na'
-    if add_naa:
-        label += " + naa/(b*g)" if donor_ref else ' + naa/b'
-    label = '(' + label + ') / w'
+    label = '$(' + label[1:-1] + ') / w$'
     if label_prefix is not None:
         label = label_prefix + ' ' + label
 
@@ -885,13 +882,33 @@ def hist_brightness(d, i=0, bins=(0, 60, 1), pdf=True, weights=None,
     plt.legend(loc='best')
 
 
-def hist_size(d, i=0, which='all', bins=(0, 600, 4), pdf=False, weights=None,
-              yscale='log', gamma=1, add_naa=False, beta=1, donor_ref=True,
-              add_aex=True, A_laser_weight=1, vline=None,
-              label_prefix=None, legend=True, color=None, plot_style=None):
-    """Plot histogram of burst sizes.
+def _get_sizes_and_formula(d, ich, gamma, beta, donor_ref, add_naa,
+                           ph_sel, naa_aexonly, naa_comp, na_comp):
+    label = ('${FD} + {FA}/\\gamma$'
+             if donor_ref else '$\\gamma {FD} + {FA}$')
+    kws = dict(gamma=gamma, beta=beta, donor_ref=donor_ref)
+    if 'PAX' in d.meas_type and ph_sel is not None:
+        kws_pax = dict(ph_sel=ph_sel, naa_aexonly=naa_aexonly,
+                       naa_comp=naa_comp, na_comp=na_comp)
+        sizes = d.burst_sizes_pax_ich(ich=ich, **dict(kws, **kws_pax))
+        label = '$ %s $' % d._burst_sizes_pax_formula(**dict(kws, **kws_pax))
+    else:
+        sizes = d.burst_sizes_ich(ich=ich, add_naa=add_naa, **kws)
+        label = label.format(FD='n_d', FA='n_a')
+        if add_naa:
+            corr = '(\\gamma\\beta) ' if donor_ref else '\\beta '
+            label = label[:-1] + ' + n_{aa} / %s$' % corr
+    return sizes, label
 
-    Parameters:
+
+def hist_size(d, i=0, which='all', bins=(0, 600, 4), pdf=False, weights=None,
+              yscale='log', gamma=1, beta=1, donor_ref=True, add_naa=False,
+              ph_sel=None, naa_aexonly=False, naa_comp=False, na_comp=False,
+              vline=None, label_prefix=None, legend=True, color=None,
+              plot_style=None):
+    """Plot histogram of "burst sizes", according to different definitions.
+
+    Arguments:
         d (Data): Data object
         i (int): channel index
         bins (array or None): array of bin edges. If len(bins) == 3
@@ -907,12 +924,17 @@ def hist_size(d, i=0, which='all', bins=(0, 600, 4), pdf=False, weights=None,
         add_naa (bool): if True, include `naa` to the total burst size.
         donor_ref (bool): convention used for corrected burst size computation.
             See :meth:`fretbursts.burstlib.Data.burst_sizes_ich` for details.
-        add_aex (bool): *PAX-only*. Whether to add signal from Aex laser period
-            to the burst size. Default True.
-            See :meth:`fretbursts.burstlib.Data.burst_sizes_pax_ich`.
-        A_laser_weight (scalar): *PAX-only*. Weight of A-ch photons during Aex
-            period (AexAem) due to the A laser.
-            See :meth:`fretbursts.burstlib.Data.burst_sizes_pax_ich`.
+        na_comp (bool): **[PAX-only]** If True, multiply the `na` term
+            by `(1 + Wa/Wd)`, where Wa and Wd are the D and A alternation
+            durations (typically Wa/Wd = 1).
+        naa_aexonly (bool): **[PAX-only]** if True, the `naa` term is
+            corrected to include only A emission due to A excitation.
+            If False, the `naa` term includes all the counts in DAexAem.
+            The `naa` term also depends on the `naa_comp` argument.
+        naa_comp (bool): **[PAX-only]** If True, multiply the `naa` term by
+            `(1 + Wa/Wd)` where Wa and Wd are the D and A alternation
+            durations (typically Wa/Wd = 1). The `naa` term also depends on
+            the `naa_aexonly` argument.
         label_prefix (string or None): a custom prefix for the legend label.
         color (string or tuple or None): matplotlib color used for the plot.
         pdf (bool): if True, normalize the histogram to obtain a PDF.
@@ -921,31 +943,22 @@ def hist_size(d, i=0, which='all', bins=(0, 600, 4), pdf=False, weights=None,
         plot_style (dict): dict of matplotlib line style passed to `plot`.
         vline (float): If not None, plot vertical line at the specified x
             position.
+
+    See also:
+        - :meth:`fretbursts.burstlib.Data.burst_sizes_ich`.
+        - :meth:`fretbursts.burstlib.Data.burst_sizes_pax_ich`.
     """
     weights = weights[i] if weights is not None else None
     if plot_style is None:
         plot_style = {}
-    which_dict = {'all': 'k', 'nd': green, 'na': red, 'naa': purple}
+    which_dict = {'all': 'k', 'nd': green, 'na': red, 'naa': purple,
+                  'nar': red, 'nda': 'C0'}
     assert which in which_dict
     if which == 'all':
-        label = '{FD} + {FA}/g' if donor_ref else 'g*{FD} + {FA}'
-        if 'PAX' in d.meas_type:
-            sizes = d.burst_sizes_pax_ich(ich=i, gamma=gamma, add_aex=add_naa,
-                                          A_laser_weight=A_laser_weight,
-                                          beta=beta, donor_ref=donor_ref)
-            if not add_aex:
-                label = label.format(FD='nd', FA='na')
-            else:
-                label = label.format(FD='(nd + nda)', FA='2 * na')
-                aex = ' + Aex_weight * (naa - nar)/{corr}'
-                corr = '(g * beta)' if donor_ref else 'beta'
-                label += aex.format(corr=corr)
-        else:
-            sizes = d.burst_sizes_ich(ich=i, gamma=gamma, add_naa=add_naa,
-                                      beta=beta, donor_ref=donor_ref)
-            label = label.format(FD='nd', FA='na')
-            if add_naa:
-                label += " + naa/(g*beta)" if donor_ref else ' + naa/beta'
+        sizes, label = _get_sizes_and_formula(
+            d=d, ich=i, gamma=gamma, beta=beta, donor_ref=donor_ref,
+            add_naa=add_naa, ph_sel=ph_sel, naa_aexonly=naa_aexonly,
+            naa_comp=naa_comp, na_comp=na_comp)
     else:
         sizes = d[which][i]
         label = which
@@ -967,7 +980,7 @@ def hist_size(d, i=0, which='all', bins=(0, 600, 4), pdf=False, weights=None,
                          plot_style=plot_style, vline=vline)
     plt.xlabel('Burst size')
     if legend:
-        plt.legend(loc='best')
+        plt.legend(loc='upper right')
 
 
 def hist_size_all(d, i=0, **kwargs):
@@ -975,9 +988,11 @@ def hist_size_all(d, i=0, **kwargs):
 
     Calls :func:`hist_size` multiple times with different `which` parameters.
     """
-    fields = ['all', 'nd', 'na']
-    if d.alternated:
+    fields = ['nd', 'na']
+    if d.ALEX:
         fields.append('naa')
+    elif 'PAX' in d.meas_type:
+        fields += ['nda', 'naa']
     for which in fields:
         hist_size(d, i, which=which, **kwargs)
 
@@ -1111,6 +1126,7 @@ def hist_burst_data(
 
     if ax is None:
         ax = gca()
+    ax.set_axisbelow(True)
     pline = ax.axhline if vertical else ax.axvline
     bar = ax.barh if vertical else ax.bar
     xlabel, ylabel = ax.set_xlabel, ax.set_ylabel
@@ -1143,8 +1159,8 @@ def hist_burst_data(
     if data_name in ['E', 'S']:
         xlim(-0.19, 1.19)
 
-    hist_bar_style_ = dict(facecolor='#80b3ff', edgecolor='#5f8dd3',
-                           linewidth=1.5, alpha=0.7, label='E Histogram')
+    hist_bar_style_ = dict(facecolor='#74a9cf', edgecolor='k', alpha=1,
+                           linewidth=0.15, label='E Histogram')
     hist_bar_style_.update(**_normalize_kwargs(hist_bar_style))
 
     hist_plot_style_ = dict(linestyle='-', marker='o', markersize=6,
@@ -1153,7 +1169,7 @@ def hist_burst_data(
                                               kind='line2d'))
     if hist_style == 'bar':
         bar(fitter.hist_bins[:-1], hist_vals, fitter.hist_binwidth,
-            **hist_bar_style_)
+            align='edge', **hist_bar_style_)
     else:
         if vertical:
             ax.plot(hist_vals, fitter.hist_axis, **hist_plot_style_)
@@ -1326,7 +1342,7 @@ def hist2d_alex(d, i=0, vmin=2, vmax=0, binwidth=0.05, S_max_norm=0.8,
         hist2d_alex.gui_sel = gs.rectSelection(gcf(), gca())
 
 
-def hexbin_alex(d, i=0, vmin=0, vmax=None, gridsize=80, cmap='Spectral_r',
+def hexbin_alex(d, i=0, vmin=1, vmax=None, gridsize=80, cmap='Spectral_r',
                 E_name='E', S_name='S', **hexbin_kwargs):
     """Plot an hexbin 2D histogram for E-S.
     """
@@ -1981,24 +1997,28 @@ def dplot_48ch(d, func, sharex=True, sharey=True, layout='horiz',
                suptitle=True, title=True, title_ch=True, title_bg=True,
                title_nbursts=True, title_kws=None, xrotation=0,
                top=0.93, bottom=None, hspace=0.18, wspace=None, left=0.08,
-               right=0.96, **kwargs):
+               right=0.96, dec=1, **kwargs):
     """Plot wrapper for 48-spot measurements. Use `dplot` instead."""
     msg = "Wrong layout '%s'. Valid values: 'horiz', 'vert', '8x6'."
     assert (layout.startswith('vert') or layout.startswith('horiz') or
             layout == '8x6'), (msg % layout)
+    if dec > 1:
+        assert dec == 2 or dec == 4
+        assert layout.startswith('horiz')
     global gui_status
-    iter_ch = range(48)
+    ch_map = np.arange(48).reshape(4, 12)[::dec, ::dec]
+    iter_ch = ch_map.ravel()
     if layout == '8x6':
         nrows, ncols = 6, 8
         if figsize is None:
             figsize = (18, 6)
     else:
-        nrows, ncols = 4, 12
+        nrows, ncols = 4 // dec, 12 // dec
         if layout.startswith('vert'):
             nrows, ncols = ncols, nrows
-            iter_ch = np.arange(48).reshape(4, 12).T.ravel()
+            iter_ch = ch_map.T.ravel()
         if figsize is None:
-            figsize = (20, 7)
+            figsize = (1.5 * ncols + 2, 1.5 * nrows + 1)
             if layout.startswith('vert'):
                 figsize = figsize[1], figsize[0]
     return _iter_plot(d, func, kwargs, iter_ch, nrows, ncols, figsize, AX,
@@ -2170,8 +2190,8 @@ def _alex_hexbin_vmax(patches, vmax_fret=True, Smax=0.8):
 
 
 def alex_jointplot(d, i=0, gridsize=50, cmap='Spectral_r', kind='hex',
-                   vmax_fret=True, vmin=0, vmax=None,
-                   joint_kws=None, marginal_kws=None, marginal_color=7,
+                   vmax_fret=True, vmin=1, vmax=None,
+                   joint_kws=None, marginal_kws=None, marginal_color=10,
                    rightside_text=False, E_name='E', S_name='S'):
     """Plot an ALEX join plot: an E-S 2D histograms with marginal E and S.
 
@@ -2240,7 +2260,8 @@ def alex_jointplot(d, i=0, gridsize=50, cmap='Spectral_r', kind='hex',
         histcolor = marginal_color
     marginal_kws_ = dict(
         show_kde=True, bandwidth=0.03, binwidth=0.03,
-        hist_bar_style={'facecolor': histcolor, 'edgecolor': 'k', 'linewidth': 0.2})
+        hist_bar_style={'facecolor': histcolor, 'edgecolor': 'k',
+                        'linewidth': 0.15, 'alpha': 1})
     if marginal_kws is not None:
         marginal_kws_.update(_normalize_kwargs(marginal_kws))
 
